@@ -93,7 +93,7 @@ sub _versioncode_from_string {
     if ($string =~ /
                     (
                         ( use \s* version \s* ; \s* )?
-                        (our)? \s* \$VERSION \s* = \s* 
+                        (our)? \s* \$VER SION \s* = \s*              # trick PAUSE from parsing this line
                         (
                                            ['"] [\d\.\_]+ ['"]
                             |      q{1,2}\( \s* [\d\.\_]+ \s* \)
