@@ -2,14 +2,20 @@ package ShipIt::Step::UploadCPAN;
 use strict;
 use base 'ShipIt::Step';
 use ShipIt::Util qw(bool_prompt);
+use File::Spec;
 
 sub init {
     my ($self, $conf) = @_;
-    my $exe;
-    $exe = `which cpan-upload-http` || `which cpan-upload`;
-    chomp $exe;
+    my $exe = '';
+    foreach my $dir (File::Spec->path) {
+        $exe = 'cpan-upload-http';
+        last if -x File::Spec->catfile($dir, $exe);
+        $exe = 'cpan-upload';
+        last if -x File::Spec->catfile($dir, $exe);
+    }
     die "cpan-upload-http not found\n" unless $exe;
     $self->{exe} = $exe;
+    $self->{user} = $conf->value("UploadCPAN.user");
 }
 
 sub run {
@@ -24,7 +30,11 @@ sub run {
     }
 
     return unless bool_prompt("Upload to CPAN?", "y");
-    system($self->{exe}, $distfile) and die
+
+    my @options;
+    push @options, "-u", $self->{user}, "-p", "" # reset password in case you have ~/.pause
+        if $self->{user};
+    system($self->{exe}, @options, $distfile) and die
         "Upload failed.\n";
 }
 
